@@ -61,7 +61,7 @@ class BaseStorageBackend(metaclass=abc.ABCMeta):
         """Copies local absolute path `src` to remote `path`."""
         raise NotImplementedError("Subclasses must override this method.")
 
-    async def async_slice(self, path, length, offset=0):
+    async def async_slice(self, path, length, offset=0, binary=False):
         """Returns a slice of the blob represented by `path`."""
         raise NotImplementedError("Subclasses must override this method.")
 
@@ -143,7 +143,7 @@ class BaseStorageBackend(metaclass=abc.ABCMeta):
         """
         raise NotImplementedError("Subclasses must override this method.")
 
-    def slice(self, path, length, offset=0):
+    def slice(self, path, length, offset=0, binary=False):
         """Returns a slice of the blob represented by `path`."""
         raise NotImplementedError("Subclasses must override this method.")
 
